@@ -1,7 +1,7 @@
-/*  $Id: weather-icon.c 2366 2007-01-15 19:10:23Z nick $
+/*  $Id: weather-icon.c 2782 2007-05-26 20:04:05Z nick $
  *
  *  Copyright (c) 2003-2007 Xfce Development Team
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -34,25 +34,20 @@
 
 GdkPixbuf *
 get_icon (const gchar *number,
-          GtkIconSize  size)
+          gint         size)
 {
   GdkPixbuf *image = NULL;
   gchar     *filename;
-  gint       width, height;
 
-  gtk_icon_size_lookup (size, &width, &height);
+  filename = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s" G_DIR_SEPARATOR_S "%s.png",
+                              THEMESDIR, DEFAULT_W_THEME, number);
 
-  filename = g_strdup_printf ("%s%s%s%s%s.png",
-                              THEMESDIR, G_DIR_SEPARATOR_S,
-                              DEFAULT_W_THEME, G_DIR_SEPARATOR_S, number);
+  image = gdk_pixbuf_new_from_file_at_scale (filename, size, size, TRUE, NULL);
 
-  image = gdk_pixbuf_new_from_file_at_scale (filename,
-                                             width, height, TRUE, NULL);
+  if (G_UNLIKELY (!image))
+    g_warning ("Unable to open image: %s", filename);
 
   g_free (filename);
 
-  if (!image)
-    g_warning ("Weather Plugin: No image found");
-
   return image;
 }
