@@ -1,4 +1,4 @@
-/*  $Id: weather-icon.h 2366 2007-01-15 19:10:23Z nick $
+/*  $Id: weather-icon.h 2782 2007-05-26 20:04:05Z nick $
  *
  *  Copyright (c) 2003-2007 Xfce Development Team
  * 
@@ -22,7 +22,7 @@
 
 G_BEGIN_DECLS
 
-GdkPixbuf *get_icon (const gchar * icon, GtkIconSize size);
+GdkPixbuf *get_icon (const gchar * icon, gint size);
 
 G_END_DECLS
 
